# 0.1.2

Optimize data struct of constant.

Delete unused part from init file.

**[Important]** Storage some personal info while create a UC instance.

# 0.1.1

Add instance expires handle.

Better(might) instance getting process.

# 0.1.0

Basic abilities. Access CAS, UC, Ucloud.

No cookie expires checking, less exception handling.
